@@ -536,6 +536,36 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
         return universe.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        universe.waitForUpdate(timeout);
+    }
+
+    ArrayList<Runnable> renderingLoopTasks = new ArrayList<Runnable>();
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.add(task);
+        }
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.remove(task);
+        }
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        universe.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        universe.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         universe.setCameraInterpolateRatio(ir);
@@ -557,6 +587,11 @@ public class A3Canvas extends Canvas3D implements A3CanvasInterface {
             gc.readRaster(readRaster);
             check = false;
         }
+        synchronized(renderingLoopTasks) {
+            for (Runnable r:renderingLoopTasks) {
+                r.run();
+            }
+        }
     }
 
     @Override
