@@ -1008,6 +1008,39 @@ public interface A3CanvasInterface {
      */
     public long getUpdateInterval();
 
+    /**
+     * カメラやA3Object座標などの更新のタイミングまでwaitします。
+     * 引数はタイムアウト時間(ミリ秒)で、その時間が過ぎたら復帰します。
+     */
+    public void waitForUpdate(long timeout);
+
+    /**
+     * 1フレームごとに確実に処理を行いたいタスクを登録します。
+     * このメソッドでRunnableを実装したオブジェクトを登録すると、
+     * Canvas3DのpostSwapで実行されます。
+     */
+    public void insertTaskIntoRenderingLoop(Runnable task);
+
+    /**
+     * insertTaskIntoRenderingLoop(Runnable task)で登録した
+     * タスクの登録を解除します。
+     */
+    public void removeTaskFromRenderingLoop(Runnable task);
+
+    /**
+     * Acerola3Dのメインタイマーが起動されるごとに確実に処理を行いたい
+     * タスクを登録します。このメソッドでRunnableを実装したオブジェクトを
+     * 登録すると、A3CanvasInterface.setUpdateInterval()で指定した
+     * 間隔で繰返し実行されます。
+     */
+    public void insertTaskIntoTimerLoop(Runnable task);
+
+    /**
+     * insertTaskIntoTimerLoop(Runnable task)で登録した
+     * タスクの登録を解除します。
+     */
+    public void removeTaskFromTimerLoop(Runnable task);
+
     /**
      * カメラの補間のスピードを調節するための係数を指定します。1.0から0.0の
      * 間の数値を指定して下さい。小さいほど補間が速くなります。
