@@ -36,6 +36,7 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
     A3VirtualUniverse virtualUniverse;
     Hashtable<A3Object,BranchGroup> lockedA3Hash = new Hashtable<A3Object,BranchGroup>();
     BranchGroup cameraGroup;
+    ArrayList<Runnable> renderingLoopTasks = new ArrayList<Runnable>();
 
     /**
      * (500,500)の大きさのA3SubCanvasを作成します。
@@ -738,6 +739,11 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
             gc.readRaster(readRaster);
             check = false;
         }
+        synchronized(renderingLoopTasks) {
+            for (Runnable r:renderingLoopTasks) {
+                r.run();
+            }
+        }
     }
 
     @Override
@@ -1739,6 +1745,35 @@ public class A3SubCanvas extends Canvas3D implements A3CanvasInterface, Componen
         return virtualUniverse.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        virtualUniverse.waitForUpdate(timeout);
+    }
+
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.add(task);
+        }
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.remove(task);
+        }
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        virtualUniverse.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        virtualUniverse.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         subCamBehavior.setInterpolateRatio(ir);
