@@ -1352,6 +1352,34 @@ class A3VirtualUniverse extends VirtualUniverse implements A3CanvasInterface {
         return elapsedTime;
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        timerBehavior.waitForUpdate(timeout);
+    }
+
+    /**
+     * このメソッドはダミーです。
+     */
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+    }
+
+    /**
+     * このメソッドはダミーです。
+     */
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        timerBehavior.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        timerBehavior.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         cameraBehavior.setInterpolateRatio(ir);
