@@ -516,6 +516,31 @@ public class A3Widget extends JFrame implements A3CanvasInterface {
         return universe.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        universe.waitForUpdate(timeout);
+    }
+
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        tCanvas.insertTaskIntoRenderingLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        tCanvas.removeTaskFromRenderingLoop(task);
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        universe.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        universe.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         universe.setCameraInterpolateRatio(ir);
