@@ -471,6 +471,31 @@ public class A3Window extends JFrame implements A3CanvasInterface {
         return canvas.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        canvas.waitForUpdate(timeout);
+    }
+
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        canvas.insertTaskIntoRenderingLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        canvas.removeTaskFromRenderingLoop(task);
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        canvas.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        canvas.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         canvas.setCameraInterpolateRatio(ir);
