@@ -240,8 +240,11 @@ class ActionBehavior extends Behavior implements Cloneable {
             for (String boneName : a.tgMap.keySet()) {
                 if ((transControlUsingRootBone)&&(boneName.equals(rootBoneName))) {
                     Transform3D t = a.motion.getTransform3D(boneName,timeD);
-                    if (t!=null)
+                    if (t!=null) {
                         a3.setTransformImmediately(t);
+                        //下の1行、設計的に非常に良くないけどどうしてもここで同期を取っておきたいので入れてある
+                        a3.behavior.setNow();
+                    }
                 } else {
                     TransformGroup tg = a.tgMap.get(boneName);
                     Transform3D t = a.motion.getTransform3D(boneName,timeD);
