@@ -6,6 +6,7 @@ import javax.media.j3d.*;
 import javax.vecmath.*;
 
 import java.io.*;
+import java.util.ArrayList;
 import java.util.Arrays;
 
 import javax.imageio.ImageIO;
@@ -30,6 +31,7 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
     private static final long serialVersionUID = 1L;
 
     A3VirtualUniverse universe;
+    ArrayList<Runnable> renderingLoopTasks = new ArrayList<Runnable>();
 
     /**
      * (500,500)の大きさのJA3Canvasを作成します。
@@ -547,6 +549,35 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
         return universe.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        universe.waitForUpdate(timeout);
+    }
+
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.add(task);
+        }
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.remove(task);
+        }
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        universe.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        universe.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         universe.setCameraInterpolateRatio(ir);
@@ -567,6 +598,11 @@ public class JA3Canvas extends JCanvas3D implements A3CanvasInterface {
             gc.readRaster(readRaster);
             check = false;
         }
+        synchronized(renderingLoopTasks) {
+            for (Runnable r:renderingLoopTasks) {
+                r.run();
+            }
+        }
     }
 
     @Override
