@@ -535,6 +535,31 @@ public class JA3Canvas2 extends TransCanvas3D implements A3CanvasInterface {
         return universe.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        universe.waitForUpdate(timeout);
+    }
+
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        super.insertTaskIntoRenderingLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        super.removeTaskFromRenderingLoop(task);
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        universe.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        universe.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         universe.setCameraInterpolateRatio(ir);
