@@ -39,6 +39,7 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
     A3VirtualUniverse virtualUniverse;
     Hashtable<A3Object,BranchGroup> lockedA3Hash = new Hashtable<A3Object,BranchGroup>();
     BranchGroup cameraGroup;
+    ArrayList<Runnable> renderingLoopTasks = new ArrayList<Runnable>();
 
     /**
      * (500,500)の大きさのJA3Canvasを作成します。
@@ -748,6 +749,11 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
             gc.readRaster(readRaster);
             check = false;
         }
+        synchronized(renderingLoopTasks) {
+            for (Runnable r:renderingLoopTasks) {
+                r.run();
+            }
+        }
     }
 
     @Override
@@ -1749,6 +1755,35 @@ public class JA3SubCanvas extends JCanvas3D implements A3CanvasInterface, Compon
         return virtualUniverse.getUpdateInterval();
     }
 
+    @Override
+    public void waitForUpdate(long timeout) {
+        virtualUniverse.waitForUpdate(timeout);
+    }
+
+    @Override
+    public void insertTaskIntoRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.add(task);
+        }
+    }
+
+    @Override
+    public void removeTaskFromRenderingLoop(Runnable task) {
+        synchronized(renderingLoopTasks) {
+            renderingLoopTasks.remove(task);
+        }
+    }
+
+    @Override
+    public void insertTaskIntoTimerLoop(Runnable task) {
+        virtualUniverse.insertTaskIntoTimerLoop(task);
+    }
+
+    @Override
+    public void removeTaskFromTimerLoop(Runnable task) {
+        virtualUniverse.removeTaskFromTimerLoop(task);
+    }
+
     @Override
     public void setCameraInterpolateRatio(double ir) {
         subCamBehavior.setInterpolateRatio(ir);
