@@ -41,7 +41,13 @@ class SubCameraBehavior extends Behavior {
         cameraNowQ.normalize();
         cameraNowV.interpolate(cameraNextV,ratio);
         t.set(cameraNowQ,cameraNowV,cameraNowS);
-        tg.setTransform(t);
+        try {
+            tg.setTransform(t);
+        } catch (BadTransformException e) {
+            System.out.println("BadTransformException in SubCameraBehavior.processStimulus().");
+            cameraNowS=1.0;cameraNowQ.set(0,0,0,1);cameraNowV.set(0,0,0);
+            //e.printStackTrace();
+        }
     }
 
     /**
